Useful links
============

1. Apigee: `<http://www.youtube.com/watch?v=QpAhXa12xvU>`_
2. Http code: 
  
  * `<http://en.wikipedia.org/wiki/List_of_HTTP_status_codes>`_
  * `<http://www.w3schools.com/tags/ref_httpmessages.asp>`_

3. JSON: `<http://www.json.org/>`_
